@@ -117,9 +117,9 @@ class scETM(BaseCellModel):
             rho_fixed_emb: part of the gene embedding matrix (rho) with shape
                 [L_fixed, G], where everything is fixed. This could be a
                 pathway-gene matrix.
-            rho_trainable_emb: part of the gene embedding matrix (rho) with
-                shape [L_trainable, G], where a submatrix of shape
-                [L_trainable, G_fixed] is fixed and the rest is trainable.
+            rho_fixed_gene: part of the gene embedding matrix (rho) with
+                shape [L_trainable, G_fixed]. This will become a part of
+                self.rho_trainable_emb.
             device: device to store the model parameters.
         """
 
@@ -159,7 +159,7 @@ class scETM(BaseCellModel):
             self.rho_trainable_emb.fixed = torch.FloatTensor(rho_fixed_gene)
         if rho_fixed_emb is not None:
             assert rho_fixed_emb.shape[1] == self.n_fixed_genes + self.n_trainable_genes
-            self.rho_fixed_emb = torch.FloatTensor(rho_fixed_emb)
+            self.rho_fixed_emb = torch.FloatTensor(rho_fixed_emb).to(device)
 
         self.alpha = nn.Parameter(torch.randn(self.n_topics, self.trainable_gene_emb_dim + (self.rho_fixed_emb.shape[0] if self.rho_fixed_emb is not None else 0)))
         self._init_batch_and_global_biases()
@@ -269,13 +269,11 @@ class scETM(BaseCellModel):
 
         if not self.training:
             theta = F.softmax(mu_q_delta, dim=-1)
-            recon_log = self.decode(theta, data_dict.get('batch_indices', None))
-            fwd_dict = dict(
-                theta=theta,
-                delta=mu_q_delta,
-                recon_log=recon_log,
-                nll = (-recon_log * (normed_cells if self.normed_loss else cells)).sum()
-            )
+            fwd_dict = dict(theta=theta, delta=mu_q_delta)
+            if 'decode' in hyper_param_dict and hyper_param_dict['decode']:
+                recon_log = self.decode(theta, data_dict.get('batch_indices', None))
+                fwd_dict['recon_log'] = recon_log
+                fwd_dict['nll'] = (-recon_log * (normed_cells if self.normed_loss else cells)).sum()
             return fwd_dict
 
         recon_log = self.decode(theta, data_dict.get('batch_indices', None))
@@ -295,13 +293,13 @@ class scETM(BaseCellModel):
         
         return loss, fwd_dict, record
 
-    def get_embeddings_and_nll(self,
+    def get_all_embeddings_and_nll(self,
         adata: anndata.AnnData,
         batch_size: int = 2000,
         emb_names: Union[str, Iterable[str], None] = None,
         batch_col: str = 'batch_indices',
         inplace: bool = True
-    ) -> Union[float, Tuple[Mapping[str, np.ndarray], float]]:
+    ) -> Union[Union[None, float], Tuple[Mapping[str, np.ndarray], Union[None, float]]]:
         """Calculates cell, gene, topic embeddings and nll for the dataset.
 
         If inplace, cell embeddings will be stored to adata.obsm. You can
