@@ -86,7 +86,7 @@ class UnsupervisedTrainer:
         """
 
         if seed >= 0:
-            self._set_seed(seed)
+            set_seed(seed)
 
         self.model: BaseCellModel = model
 
@@ -141,21 +141,6 @@ class UnsupervisedTrainer:
         _logger.info(f'ckpt_dir: {self.ckpt_dir}')
         self.update_step(restore_epoch * self.steps_per_epoch)
 
-    @staticmethod
-    def _set_seed(seed: int) -> None:
-        """Sets the random seed to seed.
-
-        Args:
-            seed: the random seed.
-        """
-
-        torch.manual_seed(seed)
-        torch.backends.cudnn.deterministic = True
-        torch.backends.cudnn.benchmark = False
-        random.seed(seed)
-        np.random.seed(seed)
-        _logger.info(f'Set seed to {seed}.')
-
     @staticmethod
     def _get_kl_weight(
         epoch: int,
@@ -290,11 +275,12 @@ class UnsupervisedTrainer:
                     current_eval_kwargs = eval_kwargs.copy()
                     current_eval_kwargs['plot_fname'] = current_eval_kwargs['plot_fname'] + f'_epoch{int(self.epoch)}'
                     if self.test_adata is not self.adata:
-                        test_nll = self.model.get_cell_embeddings_and_nll(self.test_adata, self.batch_size, batch_col=batch_col)
-                        _logger.info(f'test nll: {test_nll:7.4f}')
+                        test_nll = self.model.get_cell_embeddings_and_nll(self.test_adata, self.batch_size, batch_col=batch_col, emb_names=[])
+                        if test_nll is not None:
+                            _logger.info(f'test nll: {test_nll:7.4f}')
                     else:
                         test_nll = None
-                    self.model.get_cell_embeddings_and_nll(self.adata, self.batch_size, batch_col=batch_col)
+                    self.model.get_cell_embeddings_and_nll(self.adata, self.batch_size, batch_col=batch_col, emb_names=[self.model.clustering_input])
                     result = evaluate(adata = self.adata, embedding_key = self.model.clustering_input, **current_eval_kwargs)
                     if eval_result_log_path is not None:
                         with open(eval_result_log_path, 'a+') as f:
@@ -498,3 +484,18 @@ def prepare_for_transfer(
     tgt_model = tgt_model.to(tgt_model.device)
 
     return tgt_model, tgt_dataset
+
+
+def set_seed(seed: int) -> None:
+    """Sets the random seed to seed.
+
+    Args:
+        seed: the random seed.
+    """
+
+    torch.manual_seed(seed)
+    torch.backends.cudnn.deterministic = True
+    torch.backends.cudnn.benchmark = False
+    random.seed(seed)
+    np.random.seed(seed)
+    _logger.info(f'Set seed to {seed}.')
